"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.searchActivationLogsByPayloadPiiValue = exports.listActivationLogs = exports.getActivationLog = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const timestamp_2 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveWixAutomationsActivationLogsV1ActivationLogsServiceUrl(opts) {
    const domainToMappings = {
        'bo._base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'wixbo.ai': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'wix-bo.com': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
            {
                srcPath: '/_api/activation-logs',
                destPath: '/api',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_automations-activation-log_activation-log';
/** Get activation log by ID */
function getActivationLog(payload) {
    function __getActivationLog({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_log',
            method: 'GET',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationLogsService.GetActivationLog',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationLogsServiceUrl({
                protoPath: '/v2/activation-logs/{activationId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'activationLog.createdDate' },
                        { path: 'activationLog.initiatedInfo.statusChangedDate' },
                        { path: 'activationLog.scheduledInfo.statusChangedDate' },
                        { path: 'activationLog.scheduledInfo.date' },
                        { path: 'activationLog.startedInfo.statusChangedDate' },
                        { path: 'activationLog.endedInfo.statusChangedDate' },
                        { path: 'activationLog.cancelledInfo.statusChangedDate' },
                        { path: 'activationLog.failedInfo.statusChangedDate' },
                        { path: 'activationLog.skippedInfo.statusChangedDate' },
                        { path: 'activationLog.warnings.warningDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getActivationLog;
}
exports.getActivationLog = getActivationLog;
/** List activation logs */
function listActivationLogs(payload) {
    function __listActivationLogs({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'fromCreatedDate' }, { path: 'toCreatedDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_log',
            method: 'GET',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationLogsService.ListActivationLogs',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationLogsServiceUrl({
                protoPath: '/v2/activation-logs',
                data: serializedData,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(serializedData),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'activationLogs.createdDate' },
                        { path: 'activationLogs.initiatedInfo.statusChangedDate' },
                        { path: 'activationLogs.scheduledInfo.statusChangedDate' },
                        { path: 'activationLogs.scheduledInfo.date' },
                        { path: 'activationLogs.startedInfo.statusChangedDate' },
                        { path: 'activationLogs.endedInfo.statusChangedDate' },
                        { path: 'activationLogs.cancelledInfo.statusChangedDate' },
                        { path: 'activationLogs.failedInfo.statusChangedDate' },
                        { path: 'activationLogs.skippedInfo.statusChangedDate' },
                        { path: 'activationLogs.warnings.warningDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __listActivationLogs;
}
exports.listActivationLogs = listActivationLogs;
/**
 * Search activation logs by payload pii value
 * Entire field value match is supported
 * Supported are emails, phones and guids
 */
function searchActivationLogsByPayloadPiiValue(payload) {
    function __searchActivationLogsByPayloadPiiValue({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'fromCreatedDate' }, { path: 'toCreatedDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_log',
            method: 'POST',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationLogsService.SearchActivationLogsByPayloadPiiValue',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationLogsServiceUrl({
                protoPath: '/v2/activation-logs/search-by-payload-pii-value',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'activationLogs.createdDate' },
                        { path: 'activationLogs.initiatedInfo.statusChangedDate' },
                        { path: 'activationLogs.scheduledInfo.statusChangedDate' },
                        { path: 'activationLogs.scheduledInfo.date' },
                        { path: 'activationLogs.startedInfo.statusChangedDate' },
                        { path: 'activationLogs.endedInfo.statusChangedDate' },
                        { path: 'activationLogs.cancelledInfo.statusChangedDate' },
                        { path: 'activationLogs.failedInfo.statusChangedDate' },
                        { path: 'activationLogs.skippedInfo.statusChangedDate' },
                        { path: 'activationLogs.warnings.warningDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __searchActivationLogsByPayloadPiiValue;
}
exports.searchActivationLogsByPayloadPiiValue = searchActivationLogsByPayloadPiiValue;
//# sourceMappingURL=automations-activation-logs-v1-activation-log-activation-log.http.js.map