"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebhookIdentityType = exports.FilterBy = exports.IdentifierType = exports.Origin = exports.AutomationConfigurationStatus = exports.Type = exports.Operator = exports.TimeUnit = exports.Domain = exports.WarningReason = exports.Status = exports.SkipReason = exports.ErrorReason = exports.CancellationReason = exports.Target = void 0;
var Target;
(function (Target) {
    Target["UNKNOWN_TARGET"] = "UNKNOWN_TARGET";
    Target["SCHEDULE"] = "SCHEDULE";
    Target["IMMEDIATE"] = "IMMEDIATE";
})(Target || (exports.Target = Target = {}));
var CancellationReason;
(function (CancellationReason) {
    CancellationReason["UNKNOWN_CANCELLATION_REASON"] = "UNKNOWN_CANCELLATION_REASON";
    /** Indicating that the activation was cancelled directly */
    CancellationReason["EVENT_CANCELLED"] = "EVENT_CANCELLED";
    /** Indicating that the activation is cancelled because the automation was deactivated */
    CancellationReason["AUTOMATION_DEACTIVATED"] = "AUTOMATION_DEACTIVATED";
    /** Indicating that the activation is cancelled because the automation was deleted */
    CancellationReason["AUTOMATION_DELETED"] = "AUTOMATION_DELETED";
    /** Indicating that the activation is cancelled after the automation schedule time was reached */
    CancellationReason["CANCELLED_BY_REFRESH_PAYLOAD"] = "CANCELLED_BY_REFRESH_PAYLOAD";
    /** Indicates that the activation was cancelled due to a UoU GDPR "Right to be Forgotten" request. */
    CancellationReason["CANCELLED_BY_GDPR_REQUEST"] = "CANCELLED_BY_GDPR_REQUEST";
})(CancellationReason || (exports.CancellationReason = CancellationReason = {}));
var ErrorReason;
(function (ErrorReason) {
    /** Unexpected error reason */
    ErrorReason["UNEXPECTED_ERROR_REASON"] = "UNEXPECTED_ERROR_REASON";
    /** Failed to evaluate the schedule date expression */
    ErrorReason["SCHEDULE_DATE_EVALUATION_FAILED"] = "SCHEDULE_DATE_EVALUATION_FAILED";
})(ErrorReason || (exports.ErrorReason = ErrorReason = {}));
var SkipReason;
(function (SkipReason) {
    SkipReason["UNKNOWN_SKIP_REASON"] = "UNKNOWN_SKIP_REASON";
    /** Activation was skipped because the scheduled execution time had already passed at the time of execution */
    SkipReason["SCHEDULE_DATE_EXPIRED"] = "SCHEDULE_DATE_EXPIRED";
    /** Activation was skipped because the trigger filters defined in the automation did not match the payload. */
    SkipReason["TRIGGER_FILTERS_NOT_PASSED"] = "TRIGGER_FILTERS_NOT_PASSED";
    /** Activation was skipped because it exceeded the configured rate limit (maximum number of executions allowed in a time period). */
    SkipReason["RATE_LIMIT_EXCEEDED"] = "RATE_LIMIT_EXCEEDED";
    /** Activation was skipped because an event with the same idempotency key was already processed. */
    SkipReason["EVENT_ALREADY_PROCESSED"] = "EVENT_ALREADY_PROCESSED";
})(SkipReason || (exports.SkipReason = SkipReason = {}));
var Status;
(function (Status) {
    Status["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
    /** This indicates activation is not started yet (no action has run yet) */
    Status["INITIATED"] = "INITIATED";
    /** The activation is in scheduled status when the automation has future date or debounce defined and we're in the waiting stage (no action has run yet) */
    Status["SCHEDULED"] = "SCHEDULED";
    /** This indicates the automation activation has started and currently in progress */
    Status["STARTED"] = "STARTED";
    /** This indicates all the automation actions were handled either by invoking them, skipping them etc. */
    Status["ENDED"] = "ENDED";
    /** This indicates the activation was cancelled */
    Status["CANCELLED"] = "CANCELLED";
    /**
     * This indicates the activation failed to start
     * Note that failure in the activation of a single action will not result a failure in activation of the entire automation
     */
    Status["FAILED"] = "FAILED";
    /**
     * Indicates that the automation activation was skipped without executing any actions.
     * Note that an activation will either be skipped immediately or move to INITIATED state.
     */
    Status["SKIPPED"] = "SKIPPED";
})(Status || (exports.Status = Status = {}));
var WarningReason;
(function (WarningReason) {
    WarningReason["UNKNOWN_WARNING_REASON"] = "UNKNOWN_WARNING_REASON";
    /** Failed to enrich payload with studio site enrichment */
    WarningReason["STUDIO_SITE_ENRICHMENT_FAILED"] = "STUDIO_SITE_ENRICHMENT_FAILED";
    /** Failed to refresh payload data */
    WarningReason["REFRESH_PAYLOAD_FAILED"] = "REFRESH_PAYLOAD_FAILED";
    /** Failed to retrieve contact information */
    WarningReason["GET_CONTACT_ENRICHMENT_FAILED"] = "GET_CONTACT_ENRICHMENT_FAILED";
    /** Failed to retrieve member information */
    WarningReason["GET_MEMBER_ENRICHMENT_FAILED"] = "GET_MEMBER_ENRICHMENT_FAILED";
})(WarningReason || (exports.WarningReason = WarningReason = {}));
var Domain;
(function (Domain) {
    /** User domain (default). */
    Domain["USER"] = "USER";
    /** Wix domain. */
    Domain["WIX"] = "WIX";
})(Domain || (exports.Domain = Domain = {}));
var TimeUnit;
(function (TimeUnit) {
    TimeUnit["UNKNOWN_TIME_UNIT"] = "UNKNOWN_TIME_UNIT";
    TimeUnit["MINUTES"] = "MINUTES";
    TimeUnit["HOURS"] = "HOURS";
    TimeUnit["DAYS"] = "DAYS";
    TimeUnit["WEEKS"] = "WEEKS";
    TimeUnit["MONTHS"] = "MONTHS";
})(TimeUnit || (exports.TimeUnit = TimeUnit = {}));
var Operator;
(function (Operator) {
    Operator["UNKNOWN_OPERATOR"] = "UNKNOWN_OPERATOR";
    Operator["OR"] = "OR";
    Operator["AND"] = "AND";
})(Operator || (exports.Operator = Operator = {}));
var Type;
(function (Type) {
    /** Automation will be triggered according to the trigger configuration. */
    Type["UNKNOWN_ACTION_TYPE"] = "UNKNOWN_ACTION_TYPE";
    /** App defined Action. */
    Type["APP_DEFINED"] = "APP_DEFINED";
    /** Condition Action. */
    Type["CONDITION"] = "CONDITION";
    /** Delay Action. */
    Type["DELAY"] = "DELAY";
    /** RateLimit Action. */
    Type["RATE_LIMIT"] = "RATE_LIMIT";
    /** Set Variables Action. */
    Type["SET_VARIABLES"] = "SET_VARIABLES";
    /** Output Action. */
    Type["OUTPUT"] = "OUTPUT";
})(Type || (exports.Type = Type = {}));
var AutomationConfigurationStatus;
(function (AutomationConfigurationStatus) {
    /** unused */
    AutomationConfigurationStatus["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
    /** Automation will be triggered according to the trigger configuration */
    AutomationConfigurationStatus["ACTIVE"] = "ACTIVE";
    /** Automation will not be triggered */
    AutomationConfigurationStatus["INACTIVE"] = "INACTIVE";
})(AutomationConfigurationStatus || (exports.AutomationConfigurationStatus = AutomationConfigurationStatus = {}));
var Origin;
(function (Origin) {
    /** Default value. This is unused. */
    Origin["UNKNOWN_ORIGIN"] = "UNKNOWN_ORIGIN";
    /** User created automation. */
    Origin["USER"] = "USER";
    /** Automation created by application (site specific). */
    Origin["APPLICATION"] = "APPLICATION";
    /** Preinstalled application automation. */
    Origin["PREINSTALLED"] = "PREINSTALLED";
    /** Automation created from a recipe. */
    Origin["RECIPE"] = "RECIPE";
})(Origin || (exports.Origin = Origin = {}));
/** Type of identifier used to look up activation logs */
var IdentifierType;
(function (IdentifierType) {
    IdentifierType["UNKNOWN_TYPE"] = "UNKNOWN_TYPE";
})(IdentifierType || (exports.IdentifierType = IdentifierType = {}));
/** FilterBy */
var FilterBy;
(function (FilterBy) {
    FilterBy["UNKNOWN_TYPE"] = "UNKNOWN_TYPE";
})(FilterBy || (exports.FilterBy = FilterBy = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
//# sourceMappingURL=automations-activation-logs-v1-activation-log-activation-log.types.js.map