import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixAutomationsActivationLogsV1ActivationLogsServiceUrl(opts) {
    const domainToMappings = {
        'bo._base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'wixbo.ai': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'wix-bo.com': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
            {
                srcPath: '/_api/activation-logs',
                destPath: '/api',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_automations-activation-log_activation-log';
/** Get activation log by ID */
export function getActivationLog(payload) {
    function __getActivationLog({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_log',
            method: 'GET',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationLogsService.GetActivationLog',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationLogsServiceUrl({
                protoPath: '/v2/activation-logs/{activationId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'activationLog.createdDate' },
                        { path: 'activationLog.initiatedInfo.statusChangedDate' },
                        { path: 'activationLog.scheduledInfo.statusChangedDate' },
                        { path: 'activationLog.scheduledInfo.date' },
                        { path: 'activationLog.startedInfo.statusChangedDate' },
                        { path: 'activationLog.endedInfo.statusChangedDate' },
                        { path: 'activationLog.cancelledInfo.statusChangedDate' },
                        { path: 'activationLog.failedInfo.statusChangedDate' },
                        { path: 'activationLog.skippedInfo.statusChangedDate' },
                        { path: 'activationLog.warnings.warningDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getActivationLog;
}
/** List activation logs */
export function listActivationLogs(payload) {
    function __listActivationLogs({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'fromCreatedDate' }, { path: 'toCreatedDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_log',
            method: 'GET',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationLogsService.ListActivationLogs',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationLogsServiceUrl({
                protoPath: '/v2/activation-logs',
                data: serializedData,
                host,
            }),
            params: toURLSearchParams(serializedData),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'activationLogs.createdDate' },
                        { path: 'activationLogs.initiatedInfo.statusChangedDate' },
                        { path: 'activationLogs.scheduledInfo.statusChangedDate' },
                        { path: 'activationLogs.scheduledInfo.date' },
                        { path: 'activationLogs.startedInfo.statusChangedDate' },
                        { path: 'activationLogs.endedInfo.statusChangedDate' },
                        { path: 'activationLogs.cancelledInfo.statusChangedDate' },
                        { path: 'activationLogs.failedInfo.statusChangedDate' },
                        { path: 'activationLogs.skippedInfo.statusChangedDate' },
                        { path: 'activationLogs.warnings.warningDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __listActivationLogs;
}
/**
 * Search activation logs by payload pii value
 * Entire field value match is supported
 * Supported are emails, phones and guids
 */
export function searchActivationLogsByPayloadPiiValue(payload) {
    function __searchActivationLogsByPayloadPiiValue({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'fromCreatedDate' }, { path: 'toCreatedDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_log',
            method: 'POST',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationLogsService.SearchActivationLogsByPayloadPiiValue',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationLogsServiceUrl({
                protoPath: '/v2/activation-logs/search-by-payload-pii-value',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'activationLogs.createdDate' },
                        { path: 'activationLogs.initiatedInfo.statusChangedDate' },
                        { path: 'activationLogs.scheduledInfo.statusChangedDate' },
                        { path: 'activationLogs.scheduledInfo.date' },
                        { path: 'activationLogs.startedInfo.statusChangedDate' },
                        { path: 'activationLogs.endedInfo.statusChangedDate' },
                        { path: 'activationLogs.cancelledInfo.statusChangedDate' },
                        { path: 'activationLogs.failedInfo.statusChangedDate' },
                        { path: 'activationLogs.skippedInfo.statusChangedDate' },
                        { path: 'activationLogs.warnings.warningDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __searchActivationLogsByPayloadPiiValue;
}
//# sourceMappingURL=automations-activation-logs-v1-activation-log-activation-log.http.js.map