import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixAutomationsActivationLogsV1ActivationLog from './automations-activation-logs-v1-activation-log-activation-log.http.js';
export var Target;
(function (Target) {
    Target["UNKNOWN_TARGET"] = "UNKNOWN_TARGET";
    Target["SCHEDULE"] = "SCHEDULE";
    Target["IMMEDIATE"] = "IMMEDIATE";
})(Target || (Target = {}));
export var CancellationReason;
(function (CancellationReason) {
    CancellationReason["UNKNOWN_CANCELLATION_REASON"] = "UNKNOWN_CANCELLATION_REASON";
    /** Indicating that the activation was cancelled directly */
    CancellationReason["EVENT_CANCELLED"] = "EVENT_CANCELLED";
    /** Indicating that the activation is cancelled because the automation was deactivated */
    CancellationReason["AUTOMATION_DEACTIVATED"] = "AUTOMATION_DEACTIVATED";
    /** Indicating that the activation is cancelled because the automation was deleted */
    CancellationReason["AUTOMATION_DELETED"] = "AUTOMATION_DELETED";
    /** Indicating that the activation is cancelled after the automation schedule time was reached */
    CancellationReason["CANCELLED_BY_REFRESH_PAYLOAD"] = "CANCELLED_BY_REFRESH_PAYLOAD";
    /** Indicates that the activation was cancelled due to a UoU GDPR "Right to be Forgotten" request. */
    CancellationReason["CANCELLED_BY_GDPR_REQUEST"] = "CANCELLED_BY_GDPR_REQUEST";
})(CancellationReason || (CancellationReason = {}));
export var ErrorReason;
(function (ErrorReason) {
    /** Unexpected error reason */
    ErrorReason["UNEXPECTED_ERROR_REASON"] = "UNEXPECTED_ERROR_REASON";
    /** Failed to evaluate the schedule date expression */
    ErrorReason["SCHEDULE_DATE_EVALUATION_FAILED"] = "SCHEDULE_DATE_EVALUATION_FAILED";
})(ErrorReason || (ErrorReason = {}));
export var SkipReason;
(function (SkipReason) {
    SkipReason["UNKNOWN_SKIP_REASON"] = "UNKNOWN_SKIP_REASON";
    /** Activation was skipped because the scheduled execution time had already passed at the time of execution */
    SkipReason["SCHEDULE_DATE_EXPIRED"] = "SCHEDULE_DATE_EXPIRED";
    /** Activation was skipped because the trigger filters defined in the automation did not match the payload. */
    SkipReason["TRIGGER_FILTERS_NOT_PASSED"] = "TRIGGER_FILTERS_NOT_PASSED";
    /** Activation was skipped because it exceeded the configured rate limit (maximum number of executions allowed in a time period). */
    SkipReason["RATE_LIMIT_EXCEEDED"] = "RATE_LIMIT_EXCEEDED";
    /** Activation was skipped because an event with the same idempotency key was already processed. */
    SkipReason["EVENT_ALREADY_PROCESSED"] = "EVENT_ALREADY_PROCESSED";
})(SkipReason || (SkipReason = {}));
export var Status;
(function (Status) {
    Status["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
    /** This indicates activation is not started yet (no action has run yet) */
    Status["INITIATED"] = "INITIATED";
    /** The activation is in scheduled status when the automation has future date or debounce defined and we're in the waiting stage (no action has run yet) */
    Status["SCHEDULED"] = "SCHEDULED";
    /** This indicates the automation activation has started and currently in progress */
    Status["STARTED"] = "STARTED";
    /** This indicates all the automation actions were handled either by invoking them, skipping them etc. */
    Status["ENDED"] = "ENDED";
    /** This indicates the activation was cancelled */
    Status["CANCELLED"] = "CANCELLED";
    /**
     * This indicates the activation failed to start
     * Note that failure in the activation of a single action will not result a failure in activation of the entire automation
     */
    Status["FAILED"] = "FAILED";
    /**
     * Indicates that the automation activation was skipped without executing any actions.
     * Note that an activation will either be skipped immediately or move to INITIATED state.
     */
    Status["SKIPPED"] = "SKIPPED";
})(Status || (Status = {}));
export var WarningReason;
(function (WarningReason) {
    WarningReason["UNKNOWN_WARNING_REASON"] = "UNKNOWN_WARNING_REASON";
    /** Failed to enrich payload with studio site enrichment */
    WarningReason["STUDIO_SITE_ENRICHMENT_FAILED"] = "STUDIO_SITE_ENRICHMENT_FAILED";
    /** Failed to refresh payload data */
    WarningReason["REFRESH_PAYLOAD_FAILED"] = "REFRESH_PAYLOAD_FAILED";
    /** Failed to retrieve contact information */
    WarningReason["GET_CONTACT_ENRICHMENT_FAILED"] = "GET_CONTACT_ENRICHMENT_FAILED";
    /** Failed to retrieve member information */
    WarningReason["GET_MEMBER_ENRICHMENT_FAILED"] = "GET_MEMBER_ENRICHMENT_FAILED";
})(WarningReason || (WarningReason = {}));
export var Domain;
(function (Domain) {
    /** User domain (default). */
    Domain["USER"] = "USER";
    /** Wix domain. */
    Domain["WIX"] = "WIX";
})(Domain || (Domain = {}));
export var TimeUnit;
(function (TimeUnit) {
    TimeUnit["UNKNOWN_TIME_UNIT"] = "UNKNOWN_TIME_UNIT";
    TimeUnit["MINUTES"] = "MINUTES";
    TimeUnit["HOURS"] = "HOURS";
    TimeUnit["DAYS"] = "DAYS";
    TimeUnit["WEEKS"] = "WEEKS";
    TimeUnit["MONTHS"] = "MONTHS";
})(TimeUnit || (TimeUnit = {}));
export var Operator;
(function (Operator) {
    Operator["UNKNOWN_OPERATOR"] = "UNKNOWN_OPERATOR";
    Operator["OR"] = "OR";
    Operator["AND"] = "AND";
})(Operator || (Operator = {}));
export var Type;
(function (Type) {
    /** Automation will be triggered according to the trigger configuration. */
    Type["UNKNOWN_ACTION_TYPE"] = "UNKNOWN_ACTION_TYPE";
    /** App defined Action. */
    Type["APP_DEFINED"] = "APP_DEFINED";
    /** Condition Action. */
    Type["CONDITION"] = "CONDITION";
    /** Delay Action. */
    Type["DELAY"] = "DELAY";
    /** RateLimit Action. */
    Type["RATE_LIMIT"] = "RATE_LIMIT";
    /** Set Variables Action. */
    Type["SET_VARIABLES"] = "SET_VARIABLES";
    /** Output Action. */
    Type["OUTPUT"] = "OUTPUT";
})(Type || (Type = {}));
export var AutomationConfigurationStatus;
(function (AutomationConfigurationStatus) {
    /** unused */
    AutomationConfigurationStatus["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
    /** Automation will be triggered according to the trigger configuration */
    AutomationConfigurationStatus["ACTIVE"] = "ACTIVE";
    /** Automation will not be triggered */
    AutomationConfigurationStatus["INACTIVE"] = "INACTIVE";
})(AutomationConfigurationStatus || (AutomationConfigurationStatus = {}));
export var Origin;
(function (Origin) {
    /** Default value. This is unused. */
    Origin["UNKNOWN_ORIGIN"] = "UNKNOWN_ORIGIN";
    /** User created automation. */
    Origin["USER"] = "USER";
    /** Automation created by application (site specific). */
    Origin["APPLICATION"] = "APPLICATION";
    /** Preinstalled application automation. */
    Origin["PREINSTALLED"] = "PREINSTALLED";
    /** Automation created from a recipe. */
    Origin["RECIPE"] = "RECIPE";
})(Origin || (Origin = {}));
/** Type of identifier used to look up activation logs */
export var IdentifierType;
(function (IdentifierType) {
    IdentifierType["UNKNOWN_TYPE"] = "UNKNOWN_TYPE";
})(IdentifierType || (IdentifierType = {}));
/** FilterBy */
export var FilterBy;
(function (FilterBy) {
    FilterBy["UNKNOWN_TYPE"] = "UNKNOWN_TYPE";
})(FilterBy || (FilterBy = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Get activation log by ID
 * @param activationId - Activation log ID
 * @public
 * @documentationMaturity preview
 * @requiredField activationId
 * @permissionId AUTOMATIONS.ACTIVATION_LOG_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @returns Activation log
 * @fqn wix.automations.activation_logs.v1.ActivationLogsService.GetActivationLog
 */
export async function getActivationLog(activationId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        activationId: activationId,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationLog.getActivationLog(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.activationLog;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { activationId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['activationId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * List activation logs
 * @public
 * @documentationMaturity preview
 * @permissionId AUTOMATIONS.ACTIVATION_LOG_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.activation_logs.v1.ActivationLogsService.ListActivationLogs
 */
export async function listActivationLogs(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        fromCreatedDate: options?.fromCreatedDate,
        toCreatedDate: options?.toCreatedDate,
        cursorPaging: options?.cursorPaging,
        includePayload: options?.includePayload,
        identifierType: options?.identifierType,
        automationIdInfo: options?.automationIdInfo,
        preinstalledIdentifierInfo: options?.preinstalledIdentifierInfo,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationLog.listActivationLogs(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                fromCreatedDate: '$[0].fromCreatedDate',
                toCreatedDate: '$[0].toCreatedDate',
                cursorPaging: '$[0].cursorPaging',
                includePayload: '$[0].includePayload',
                identifierType: '$[0].identifierType',
                automationIdInfo: '$[0].automationIdInfo',
                preinstalledIdentifierInfo: '$[0].preinstalledIdentifierInfo',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Search activation logs by payload pii value
 * Entire field value match is supported
 * Supported are emails, phones and guids
 * @param value - Value to search in the payload
 * @public
 * @documentationMaturity preview
 * @requiredField value
 * @permissionId AUTOMATIONS.ACTIVATION_LOG_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.activation_logs.v1.ActivationLogsService.SearchActivationLogsByPayloadPiiValue
 */
export async function searchActivationLogsByPayloadPiiValue(value, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        value: value,
        cursorPaging: options?.cursorPaging,
        includePayload: options?.includePayload,
        filterBy: options?.filterBy,
        automationIdInfo: options?.automationIdInfo,
        preinstalledIdentifierInfo: options?.preinstalledIdentifierInfo,
        fromCreatedDate: options?.fromCreatedDate,
        toCreatedDate: options?.toCreatedDate,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationLog.searchActivationLogsByPayloadPiiValue(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                value: '$[0]',
                cursorPaging: '$[1].cursorPaging',
                includePayload: '$[1].includePayload',
                filterBy: '$[1].filterBy',
                automationIdInfo: '$[1].automationIdInfo',
                preinstalledIdentifierInfo: '$[1].preinstalledIdentifierInfo',
                fromCreatedDate: '$[1].fromCreatedDate',
                toCreatedDate: '$[1].toCreatedDate',
            },
            singleArgumentUnchanged: false,
        }, ['value', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=automations-activation-logs-v1-activation-log-activation-log.universal.js.map